@@ -20,14 +20,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
-#include <glade/glade.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
 #include <math.h>
 #include <string.h>
+#include <gtk/gtk.h>
 
 #include "gst.h"
 #include "time-tool.h"
@@ -48,6 +47,7 @@ static gboolean flash_selected_point (gpointer data);
 static gboolean motion (GtkWidget *widget, GdkEventMotion *event, gpointer data);
 static gboolean button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data);
 static gboolean update_map (GtkWidget *w, gpointer data);
+static gboolean in_map (GtkWidget *w, GdkEventCrossing *event, gpointer data);
 static gboolean out_map (GtkWidget *w,GdkEventCrossing *event, gpointer data);
 static gboolean map (GtkWidget *widget, GdkEvent *event, gpointer data);
 static gboolean unmap (GtkWidget *widget, GdkEvent *event, gpointer data);
@@ -91,6 +91,8 @@ e_tz_map_new (GstTool *tool)
 			 G_CALLBACK (motion), (gpointer) tzmap);
 	g_signal_connect(G_OBJECT(tzmap->map), "button-press-event",
 			 G_CALLBACK (button_pressed), (gpointer) tzmap);
+        g_signal_connect(G_OBJECT (tzmap->map), "enter-notify-event",
+	                 G_CALLBACK (in_map), (gpointer) tzmap);
         g_signal_connect(G_OBJECT (tzmap->map), "leave-notify-event",
 	                 G_CALLBACK (out_map), (gpointer) tzmap);
 	
@@ -133,7 +135,7 @@ e_tz_map_get_tz_db (ETzMap *tzmap)
 }
 
 TzLocation *
-e_tz_map_get_location_by_name (ETzMap *tzmap, gchar *name)
+e_tz_map_get_location_by_name (ETzMap *tzmap, const gchar *name)
 {
 	TzLocation *tz_loc = NULL;
 	TzDB *tz_db;
@@ -187,7 +189,7 @@ e_tz_map_set_location_text (ETzMap *tzmap, const gchar *name)
 }
 
 void
-e_tz_map_set_tz_from_name (ETzMap *tzmap, gchar *name)
+e_tz_map_set_tz_from_name (ETzMap *tzmap, const gchar *name)
 {
 	TzLocation *tz_loc = NULL;
 	TzDB *tz_db;
@@ -311,16 +313,14 @@ flash_selected_point (gpointer data)
 	return TRUE;
 }
 
-
-static gboolean
-motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
+static void
+update_hover_point (ETzMap  *tzmap,
+		    gdouble  x_coord,
+		    gdouble  y_coord)
 {
-	ETzMap *tzmap;
 	double longitude, latitude;
 
-	tzmap = (ETzMap *) data;
-
-	e_map_window_to_world (tzmap->map, (double) event->x, (double) event->y,
+	e_map_window_to_world (tzmap->map, x_coord, y_coord,
 			       &longitude, &latitude);
 
 	if (tzmap->point_hover && tzmap->point_hover != tzmap->point_selected)
@@ -339,10 +339,33 @@ motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 
 	gtk_label_set_text (GTK_LABEL (((GstTimeTool *) tzmap->tool)->map_hover_label),
 			    tz_location_get_zone (e_tz_map_location_from_point (tzmap, tzmap->point_hover)));
+}
 
+static gboolean
+motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
+{
+	ETzMap *tzmap;
+	gdouble x_coord, y_coord;
+
+	tzmap = (ETzMap *) data;
+
+	gdk_event_get_coords ((GdkEvent *) event, &x_coord, &y_coord);
+	update_hover_point (tzmap, x_coord, y_coord);
 	return TRUE;
 }
 
+static gboolean
+in_map (GtkWidget *w, GdkEventCrossing *event, gpointer data)
+{
+	ETzMap *tzmap;
+	gdouble x_coord, y_coord;
+
+	tzmap = (ETzMap *) data;
+
+	gdk_event_get_coords ((GdkEvent *) event, &x_coord, &y_coord);
+	update_hover_point (tzmap, x_coord, y_coord);
+	return TRUE;
+}
 
 static gboolean
 out_map (GtkWidget *w, GdkEventCrossing *event, gpointer data)
